==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation type="unfinished">Verwijderen</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation type="unfinished">Geen</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation type="unfinished">Sluiten</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Sluiten</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Geen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Opdracht</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>DBus-aanroeping</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Cliënt</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Sneltoets</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Actie bewerken</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Sneltoets:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Beschrijving:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Ingeschakeld</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Opdracht</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;DBus-bericht</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Soort:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Op&amp;dracht:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Dienst:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Pad:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Gebruikersschil:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Methode:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globale actiebeheerder</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Toevoegen ...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Wijzigen ...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Omwisselen</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Gedrag bij meerdere acties:</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Eerste</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Laatste</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
</TS>
